Creates the disease-related age covariate vector based on the disease initiation times and adds it to the data frame
add_dis_age(data, t_init, id_var = "id", time_var = "age")A data frame with one column added. The new column will
be called dis_age. For controls, its value will be NaN.
the original data frame
A named vector containing the observed initiation or onset
time for each individual. The names, i.e. names(t_init), should
specify the individual id.
name of the id variable in data
name of the time variable in data
Other data frame handling functions:
add_factor(),
add_factor_crossing(),
adjusted_c_hat(),
new_x(),
split()