Learn R Programming

lgpr (version 1.2.5)

add_factor_crossing: Add a crossing of two factors to a data frame

Description

Add a crossing of two factors to a data frame

Usage

add_factor_crossing(data, fac1, fac2, new_name)

Value

a data frame

Arguments

data

a data frame

fac1

name of first factor, must be found in df

fac2

name of second factor, must be found in df

new_name

name of the new factor

See Also

Other data frame handling functions: add_dis_age(), add_factor(), adjusted_c_hat(), new_x(), split()