Creates the c_hat input for lgp,
so that it accounts for normalization between data points in the
"poisson" or "nb" observation model
adjusted_c_hat(y, norm_factors)a vector of length n, which can be used as
the c_hat input to the lgp function
response variable, vector of length n
normalization factors, vector of length n
Other data frame handling functions:
add_dis_age(),
add_factor(),
add_factor_crossing(),
new_x(),
split()