Learn R Programming

lgpr (version 1.2.4)

adjusted_c_hat: Set the GP mean vector, taking TMM or other normalization into account

Description

Creates the c_hat input for lgp, so that it accounts for normalization between data points in the "poisson" or "nb" observation model

Usage

adjusted_c_hat(y, norm_factors)

Value

a vector of length n, which can be used as the c_hat input to the lgp function

Arguments

y

response variable, vector of length n

norm_factors

normalization factors, vector of length n

See Also

Other data frame handling functions: add_dis_age(), add_factor_crossing(), add_factor(), new_x(), split()